@@ -1,14 +1,13 @@
 /*
  *  agShell
- *  $Id: agShell.c,v 4.29 2009/01/01 16:51:41 bkorb Exp $
+ *  $Id$
  *
- *  Time-stamp:        "2008-12-31 13:55:28 bkorb"
- *  Last Committed:    $Date: 2009/01/01 16:51:41 $
+ *  Time-stamp:        "2010-02-24 08:43:37 bkorb"
  *
  *  Manage a server shell process
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -24,6 +23,8 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+static tpChar  pCurDir    = NULL;
+
 #ifndef SHELL_ENABLED
  void closeServer( void ) { }
 
@@ -45,7 +46,6 @@
  */
 static tpfPair serverPair = { NULL, NULL };
 static pid_t   serverId   = NULLPROCESS;
-static tpChar  pCurDir    = NULL;
 static ag_bool errClose   = AG_FALSE;
 static int     logCount   = 0;
 static tCC     logIntroFmt[] = "\n\n* * * * LOG ENTRY %d * * * *\n";
@@ -55,15 +55,14 @@ tSCC   zCmdFmt[]   = "cd %s\n%s\n\necho\necho %s - %d\n";
 char const* pzLastCmd = NULL;
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by mk-fwd */
 static void
-sigHandler( int signo );
+sigHandler(int signo);
 
 static void
-serverSetup( void );
+serverSetup(void);
 
 static char*
-loadData( void );
+loadData(void);
 /* = = = END-STATIC-FORWARD = = = */
 
 
@@ -101,7 +100,7 @@ closeServer( void )
 
 
 static void
-sigHandler( int signo )
+sigHandler(int signo)
 {
     static int timeout_limit = 5;
     if ((signo == SIGALRM) && (--timeout_limit <= 0))
@@ -123,7 +122,7 @@ sigHandler( int signo )
 
 
 static void
-serverSetup( void )
+serverSetup(void)
 {
     struct sigaction  saNew;
     struct sigaction  saSave1;
@@ -374,7 +373,6 @@ openServerFP( tpfPair* pfPair, tCC** ppArgs )
     pfPair->pfWrite = fdopen( fdPair.writeFd, "w" FOPEN_BINARY_FLAG );
     return chId;
 }
-#endif /* SHELL_ENABLED */
 
 
 /*
@@ -386,7 +384,7 @@ openServerFP( tpfPair* pfPair, tCC** ppArgs )
  *  to size at the end.  Input is assumed to be an ASCII string.
  */
 static char*
-loadData( void )
+loadData(void)
 {
     char*   pzText;
     size_t  textSize;
@@ -484,7 +482,7 @@ loadData( void )
     return AGREALOC( (void*)pzText, textSize, "resizing text output" );
 }
 
-#ifdef SHELL_ENABLED
+
 /*
  *  Run a semi-permanent server shell.  The program will be the
  *  one named by the environment variable $SHELL, or default to "sh".
