@@ -1,15 +1,14 @@
 
 /*
  *  autogen.h
- *  $Id: autogen.h,v 4.35 2009/01/01 16:51:42 bkorb Exp $
+ *  $Id$
  *
- *  Time-stamp:        "2008-12-31 13:53:26 bkorb"
- *  Last Committed:    $Date: 2009/01/01 16:51:42 $
+ *  Time-stamp:        "2010-02-24 14:50:07 bkorb"
  *
  *  Global header file for AutoGen
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -29,6 +28,7 @@
 
 #include "config.h"
 #include "compat/compat.h"
+#include "compat/unlocked-io.h"
 
 #include REGEX_HEADER
 #include <libguile/scmconfig.h>
@@ -114,8 +114,9 @@ typedef struct for_info      tForInfo;
 typedef struct for_state     tForState;
 typedef struct template_lib_marker tTlibMark;
 
-#define MAX_SUFFIX_LEN    8  /* maximum length of a file name suffix */
-#define MAX_HEREMARK_LEN 64  /* max length of a here mark */
+#define MAX_SUFFIX_LEN     8  /* maximum length of a file name suffix */
+#define MAX_HEREMARK_LEN  64  /* max length of a here mark */
+#define SCRIBBLE_SIZE    256  /* much larger than any short name */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
