@@ -1,13 +1,12 @@
 /*
- *  $Id: defFind.c,v 4.23 2009/07/21 03:21:57 bkorb Exp $
+ *  $Id$
  *
- *  Time-stamp:        "2009-07-09 19:00:11 bkorb"
- *  Last Committed:    $Date: 2009/07/21 03:21:57 $
+ *  Time-stamp:        "2010-02-24 08:43:07 bkorb"
  *
  *  This module locates definitions.
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -52,7 +51,6 @@ static tDefEntry* findEntryByIndex( tDefEntry* pE, char* pzScan );
 
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by mk-fwd */
 static tDefEntry*
 findEntryByIndex( tDefEntry* pE, char* pzScan );
 
@@ -725,6 +723,11 @@ entryListSearch( char* pzName, tDefCtx* pDefCtx )
      *  an index yet).
      */
     if (defList.nestLevel == 0) {
+        if (*pzName == '.') {
+            noNesting = AG_TRUE;
+            while (IS_WHITESPACE_CHAR(*++pzName)) ;
+        }
+
         if (! IS_VAR_FIRST_CHAR(*pzName)) {
             strncpy(zDefinitionName, pzName, sizeof(zDefinitionName) - 1);
             zDefinitionName[ sizeof(zDefinitionName) - 1] = NUL;
@@ -735,11 +738,6 @@ entryListSearch( char* pzName, tDefCtx* pDefCtx )
         canonicalizeName( zDefinitionName, pzName, (int)strlen( pzName ));
         pzName = zDefinitionName;
         defList.usedCt = 0;
-
-        if (*pzName == '.') {
-            noNesting = AG_TRUE;
-            pzName++;
-        }
     }
 
     pcBrace  = pzName + strcspn( pzName, "[." );
