@@ -1,7 +1,7 @@
 /*  
  *  EDIT THIS FILE WITH CAUTION  (defParse-fsm.c)
  *  
- *  It has been AutoGen-ed  Saturday May 16, 2009 at 08:16:05 AM PDT
+ *  It has been AutoGen-ed  March  3, 2010 at 11:25:20 AM by AutoGen 5.10.1
  *  From the definitions    defParse.def
  *  and the template file   fsm
  *
@@ -40,15 +40,9 @@
 #include <stdio.h>
 #include <ctype.h>
 
-/*
- *  Do not make changes to this file, except between the START/END
- *  comments, or it will be removed the next time it is generated.
- */
-/* START === USER HEADERS === DO NOT CHANGE THIS COMMENT */
-
-static char* pz_new_name = NULL;
-
-/* END   === USER HEADERS === DO NOT CHANGE THIS COMMENT */
+#define FSM_USER_HEADERS
+#include "defParse.x"
+#undef  FSM_USER_HEADERS
 
 #ifndef NULL
 #  define NULL 0
@@ -350,240 +344,9 @@ static const size_t aszDpEvents[16] = {
 
 static int dp_invalid_transition( te_dp_state st, te_dp_event evt );
 
-/* * * * * * * * * THE CODE STARTS HERE * * * * * * * *
- *
- *  Print out an invalid transition message and return EXIT_FAILURE
- */
-static int
-dp_invalid_transition( te_dp_state st, te_dp_event evt )
-{
-    /* START == INVALID TRANS MSG == DO NOT CHANGE THIS COMMENT */
-    char const * fmt_pz = zDpStrings + DpFsmErr_off;
-    fprintf(stderr, fmt_pz, st, DP_STATE_NAME(st), evt, DP_EVT_NAME(evt));
-    /* END   == INVALID TRANS MSG == DO NOT CHANGE THIS COMMENT */
-
-    return EXIT_FAILURE;
-}
-
-static te_dp_state
-dp_do_empty_val(
-    te_dp_state initial,
-    te_dp_state maybe_next,
-    te_dp_event trans_evt )
-{
-/*  START == EMPTY VAL == DO NOT CHANGE THIS COMMENT  */
-    static char * nil_pz = NULL;
-
-    /*
-     *  Our state is either "have-name" or "indx-name" and we found a ';',
-     *  end of statement.  It is a string value with an empty string.
-     */
-    tDefEntry* pDE = findPlace( pz_new_name, NULL );
-    if (nil_pz == NULL) {
-        nil_pz = AGALOC( 1, "NUL byte" );
-        *nil_pz = NUL;
-    }
-
-    pDE->val.pzText = nil_pz;
-    pDE->valType    = VALTYP_TEXT;
-    return maybe_next;
-/*  END   == EMPTY VAL == DO NOT CHANGE THIS COMMENT  */
-}
-
-static te_dp_state
-dp_do_end_block(
-    te_dp_state initial,
-    te_dp_state maybe_next,
-    te_dp_event trans_evt )
-{
-/*  START == END BLOCK == DO NOT CHANGE THIS COMMENT  */
-    if (stackDepth <= 0)
-        yyerror( (void*)"Too many close braces" );
-
-    pCurrentEntry = ppParseStack[ stackDepth-- ];
-    return maybe_next;
-/*  END   == END BLOCK == DO NOT CHANGE THIS COMMENT  */
-}
-
-static te_dp_state
-dp_do_have_name_lit_eq(
-    te_dp_state initial,
-    te_dp_state maybe_next,
-    te_dp_event trans_evt )
-{
-/*  START == HAVE NAME LIT EQ == DO NOT CHANGE THIS COMMENT  */
-    /*
-     *  Create a new entry but defer "makeMacro" call until we have the
-     *  assigned value.
-     */
-    findPlace( pz_new_name, NULL );
-    return maybe_next;
-/*  END   == HAVE NAME LIT EQ == DO NOT CHANGE THIS COMMENT  */
-}
-
-static te_dp_state
-dp_do_indexed_name(
-    te_dp_state initial,
-    te_dp_state maybe_next,
-    te_dp_event trans_evt )
-{
-/*  START == INDEXED NAME == DO NOT CHANGE THIS COMMENT  */
-    /*
-     *  Create a new entry with a specified indes, but defer "makeMacro" call
-     *  until we have the assigned value.
-     */
-    findPlace( pz_new_name, pz_token );
-    return maybe_next;
-/*  END   == INDEXED NAME == DO NOT CHANGE THIS COMMENT  */
-}
-
-static te_dp_state
-dp_do_invalid(
-    te_dp_state initial,
-    te_dp_state maybe_next,
-    te_dp_event trans_evt )
-{
-/*  START == INVALID == DO NOT CHANGE THIS COMMENT  */
-    dp_invalid_transition( initial, trans_evt );
-    yyerror( (void*)"invalid transition" );
-    /* NOTREACHED */
-    return DP_ST_INVALID;
-/*  END   == INVALID == DO NOT CHANGE THIS COMMENT  */
-}
-
-static te_dp_state
-dp_do_need_name_end(
-    te_dp_state initial,
-    te_dp_state maybe_next,
-    te_dp_event trans_evt )
-{
-/*  START == NEED NAME END == DO NOT CHANGE THIS COMMENT  */
-    if (stackDepth != 0)
-        yyerror( (void*)"definition blocks were left open" );
-
-    /*
-     *  We won't be using the parse stack any more.
-     *  We only process definitions once.
-     */
-    if (ppParseStack != parseStack)
-        AGFREE( ppParseStack );
-
-    /*
-     *  The seed has now done its job.  The real root of the
-     *  definitions is the first entry off of the seed.
-     */
-    rootDefCtx.pDefs = rootDefCtx.pDefs->val.pDefEntry;
-    return maybe_next;
-/*  END   == NEED NAME END == DO NOT CHANGE THIS COMMENT  */
-}
-
-static te_dp_state
-dp_do_need_name_var_name(
-    te_dp_state initial,
-    te_dp_state maybe_next,
-    te_dp_event trans_evt )
-{
-/*  START == NEED NAME VAR NAME == DO NOT CHANGE THIS COMMENT  */
-    pz_new_name = pz_token;
-    return maybe_next;
-/*  END   == NEED NAME VAR NAME == DO NOT CHANGE THIS COMMENT  */
-}
-
-static te_dp_state
-dp_do_next_val(
-    te_dp_state initial,
-    te_dp_state maybe_next,
-    te_dp_event trans_evt )
-{
-/*  START == NEXT VAL == DO NOT CHANGE THIS COMMENT  */
-    /*
-     *  Clone the entry name of the current entry.
-     */
-    findPlace( pCurrentEntry->pzDefName, NULL );
-    return maybe_next;
-/*  END   == NEXT VAL == DO NOT CHANGE THIS COMMENT  */
-}
-
-static te_dp_state
-dp_do_start_block(
-    te_dp_state initial,
-    te_dp_state maybe_next,
-    te_dp_event trans_evt )
-{
-/*  START == START BLOCK == DO NOT CHANGE THIS COMMENT  */
-    if (pCurrentEntry->valType == VALTYP_TEXT)
-        yyerror( (void*)"assigning a block value to text name" );
-    pCurrentEntry->valType = VALTYP_BLOCK; /* in case not yet determined */
-
-    if (++stackDepth >= stackSize) {
-        tDefEntry** ppDE;
-        stackSize += stackSize / 2;
-
-        if (ppParseStack == parseStack) {
-            ppDE = AGALOC( stackSize * sizeof(void*), "def stack" );
-            memcpy( ppDE, parseStack, sizeof( parseStack ));
-        } else {
-            ppDE = AGREALOC( ppParseStack, stackSize * sizeof(void*),
-                             "stretch def stack" );
-        }
-        ppParseStack = ppDE;
-    }
-    ppParseStack[ stackDepth ] = pCurrentEntry;
-    pCurrentEntry = NULL;
-    return maybe_next;
-/*  END   == START BLOCK == DO NOT CHANGE THIS COMMENT  */
-}
-
-static te_dp_state
-dp_do_str_value(
-    te_dp_state initial,
-    te_dp_state maybe_next,
-    te_dp_event trans_evt )
-{
-/*  START == STR VALUE == DO NOT CHANGE THIS COMMENT  */
-    if (pCurrentEntry->valType == VALTYP_BLOCK)
-        yyerror( (void*)"assigning a block value to text name" );
-
-    pCurrentEntry->val.pzText = pz_token;
-    pCurrentEntry->valType = VALTYP_TEXT;
-
-    /*
-     *  The "here string" marker is the line before where the text starts.
-     */
-    if (trans_evt == DP_EV_HERE_STRING)
-        pCurrentEntry->srcLineNum++;
-    return maybe_next;
-/*  END   == STR VALUE == DO NOT CHANGE THIS COMMENT  */
-}
-
-static te_dp_state
-dp_do_tpl_name(
-    te_dp_state initial,
-    te_dp_state maybe_next,
-    te_dp_event trans_evt )
-{
-/*  START == TPL NAME == DO NOT CHANGE THIS COMMENT  */
-    /*
-     *  Allow this routine to be called multiple times.
-     *  This may happen if we include another definition file.
-     */
-    if (rootDefCtx.pDefs == NULL) {
-        tSCC   zBogus[] = "@BOGUS@";
-        static tDefEntry seed = {
-            NULL, NULL, NULL, NULL, (char*)zBogus, 0, { NULL },
-            (char*)zBogus, 0, VALTYP_BLOCK };
-
-        rootDefCtx.pDefs = &seed;
-
-        if (! HAVE_OPT(OVERRIDE_TPL))
-             pzTemplFileName = pz_token;
-
-        stackDepth = 0;
-        ppParseStack[0] = &seed;
-    }
-    return maybe_next;
-/*  END   == TPL NAME == DO NOT CHANGE THIS COMMENT  */
-}
+#define FSM_HANDLER_CODE
+#include "defParse.x"
+#undef  FSM_HANDLER_CODE
 
 /*
  *  Run the FSM.  Will return DP_ST_DONE or DP_ST_INVALID
@@ -598,14 +361,17 @@ dp_run_fsm( void )
 
     while (dp_state < DP_ST_INVALID) {
 
-        /* START == FIND TRANSITION == DO NOT CHANGE THIS COMMENT */
-        trans_evt = yylex();
-        /* END   == FIND TRANSITION == DO NOT CHANGE THIS COMMENT */
+#define FSM_FIND_TRANSITION
+#include "defParse.x"
+#undef  FSM_FIND_TRANSITION
 
+#ifndef __COVERITY__
         if (trans_evt >= DP_EV_INVALID) {
             nxtSt = DP_ST_INVALID;
             pT    = dp_do_invalid;
-        } else {
+        } else
+#endif /* __COVERITY__ */
+        {
             const t_dp_transition* pTT =
             dp_trans_table[ dp_state ] + trans_evt;
             nxtSt = pTT->next_state;
