@@ -1,15 +1,13 @@
 /*
  *  expExtract.c
- *  $Id: expExtract.c,v 4.21 2008/01/23 00:36:01 bkorb Exp $
+ *  $Id$
  *
- *  Time-stamp:        "2007-07-04 11:18:16 bkorb"
- *  Last Committed:    $Date: 2008/01/23 00:36:01 $
+ *  Time-stamp:        "2010-02-24 08:43:02 bkorb"
  *
  *  This module implements a file extraction function.
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
- *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -26,7 +24,6 @@
  */
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by mk-fwd */
 static char const*
 loadExtractData( char const* pzNewFile );
 
@@ -95,10 +92,19 @@ loadExtractData( char const* pzNewFile )
      *  Suck up the file.  We must read it all.
      */
     {
+        struct stat stbf;
         FILE* fp = fopen( pzNewFile, "r" );
         if (fp == NULL)
             goto bad_return;
 
+        if (fstat(fileno(fp), &stbf) != 0) {
+            fclose(fp);
+            goto bad_return;
+        }
+
+        if (outTime <= stbf.st_mtime)
+            outTime = stbf.st_mtime + 1;
+
         do  {
             size_t sz = fread(pzIn, (size_t)1, (size_t)sbuf.st_size, fp);
             if (sz == 0) {
@@ -112,7 +118,7 @@ loadExtractData( char const* pzNewFile )
         } while (sbuf.st_size > 0);
 
         *pzIn = NUL;
-        fclose( fp );
+        fclose(fp);
     }
 
     return pzText;
@@ -242,19 +248,30 @@ extractText( char const* pzText, char const* pzStart, char const* pzEnd,
  * macro with a Guile/scheme function, extract the text you want to keep
  * with this extract function.  Just remember you should delete it at the
  * end, too.  Here is an example from my Finite State Machine generator:
- * @end table
  *
  * @example
  * [+ AutoGen5 Template  -*- Mode: text -*-
- *    h=%s-fsm.h   c=%s-fsm.c
- *    (shellf
- *    "[ -f %1$s-fsm.h ] && mv -f %1$s-fsm.h .fsm.head
- *     [ -f %1$s-fsm.c ] && mv -f %1$s-fsm.c .fsm.code" (base-name)) +]
+ * h=%s-fsm.h   c=%s-fsm.c
+ * (shellf
+ * "test -f %1$s-fsm.h && mv -f %1$s-fsm.h .fsm.head
+ *  test -f %1$s-fsm.c && mv -f %1$s-fsm.c .fsm.code" (base-name))
+ * +]
  * @end example
  *
  * This code will move the two previously produced output files to files
  * named ".fsm.head" and ".fsm.code".  At the end of the 'c' output
  * processing, I delete them.
+ *
+ * @item also NB:
+ * This function presumes that the output file ought to be editable so
+ * that the code between the @code{START} and @code{END} marks can be edited
+ * by the template user.  Consequently, when the @code{(extract ...)} function
+ * is invoked, if the @code{writable} option has not been specified, then
+ * it will be set at that point.  If this is not the desired behavior, the
+ * @code{--not-writable} command line option will override this.
+ * Also, you may use the guile function @code{(chmod "file" mode-value)}
+ * to override whatever AutoGen is using for the result mode.
+ * @end table
 =*/
 SCM
 ag_scm_extract( SCM file, SCM marker, SCM caveat, SCM def )
