@@ -1,14 +1,13 @@
 
 /*
- *  $Id: expOutput.c,v 4.30 2007/12/10 20:03:09 bkorb Exp $
+ *  $Id$
  *
- *  Time-stamp:        "2007-12-05 06:19:49 bkorb"
- *  Last Committed:    $Date: 2007/12/10 20:03:09 $
+ *  Time-stamp:        "2010-02-24 08:42:59 bkorb"
  *
  *  This module implements the output file manipulation function
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2007 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -42,7 +41,6 @@ static tSuspendName*  pSuspended  = NULL;
 static int            outputDepth = 1;
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by mk-fwd */
 static void
 addWriteAccess( char* pzFileName );
 /* = = = END-STATIC-FORWARD = = = */
@@ -331,7 +329,7 @@ ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
             if (strcmp( pSuspended[ ix ].pzSuspendName, pzName ) == 0) {
                 tFpStack* pSaveFp = pCurFp;
                 pCurFp = pSuspended[ ix ].pOutDesc;
-                (void) ag_scm_emit( res );
+                (void) ag_scm_emit(res);
                 pCurFp = pSaveFp;
                 return SCM_UNDEFINED;
             }
@@ -343,7 +341,7 @@ ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
      *  "0" (zero) representing the current output and "1" the last suspended
      *  output.  If the number is out of range, we'll fall through to the abend.
      */
-    else if (AG_SCM_NUM_P(port)) do {
+    else if (AG_SCM_NUM_P(port)) {
         tFpStack* pSaveFp = pCurFp;
         unsigned long val = gh_scm2ulong(port);
 
@@ -355,22 +353,61 @@ ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
             }
         }
 
-        (void) ag_scm_emit( res );
+        (void) ag_scm_emit(res);
         pCurFp  = pSaveFp;
         return SCM_UNDEFINED;
-
-    fprintf_woops: ;
-    } while (0);
+    }
 
     /*
      *  Still here?  We have a bad "port" specification.
      */
-    AG_ABEND( invalid_z );
+    fprintf_woops:
+
+    AG_ABEND(invalid_z);
     /* NOTREACHED */
     return SCM_UNDEFINED;
 }
 
 
+/*
+ * Some common code for creating a new file
+ */
+LOCAL void
+open_output_file(char const * fname, size_t nmsz, char const * mode, int flags)
+{
+    char *    pz;
+    tFpStack* p  = AGALOC(sizeof(*p), "out file stack");
+
+    pz = (char*)AGALOC(nmsz + 1, "file name string");
+    memcpy( pz, fname, nmsz );
+    pz[ nmsz ] = NUL;
+    memset(p, NUL, sizeof(*p));
+    p->pzOutName = pz;
+
+    /*
+     *  IF we are creating the file and we are allowed to unlink the output,
+     *  then start by unlinking the thing.
+     */
+    if ((*mode == 'w') && ((flags & FPF_NOUNLINK) == 0)) {
+        if ((unlink(pz) != 0) && (errno != ENOENT))
+            AG_ABEND(aprf(zCannot, errno, "unlink", pz, strerror(errno)));
+    }
+
+    p->pFile = fopen(pz, mode);
+    if (p->pFile == NULL)
+        AG_ABEND(aprf( zCannot, errno, "open for output", pz, strerror(errno)));
+
+    p->pPrev = pCurFp;
+    pCurFp   = p;
+    p->flags = FPF_FREE | flags;
+    outputDepth++;
+
+    addWriteAccess(pz);
+
+    if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
+        fprintf(pfTrace, "open_output_file '%s' mode %s\n", fname, mode);
+}
+
 /*=gfunc out_push_add
  *
  * what:   append output to file
@@ -383,38 +420,14 @@ ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
 SCM
 ag_scm_out_push_add( SCM new_file )
 {
-    tFpStack* p;
-    char*  pzNewFile;
+    static char const append_mode[] = "a" FOPEN_BINARY_FLAG "+";
 
     if (! AG_SCM_STRING_P( new_file ))
-        return SCM_UNDEFINED;
+        AG_ABEND("No output file specified to add to");
 
-    {
-        size_t sz = AG_SCM_STRLEN( new_file );
-        pzNewFile = (char*)AGALOC( sz + 1, "append file name string" );
-        memcpy( pzNewFile, AG_SCM_CHARS( new_file ), sz );
-        pzNewFile[ sz ] = NUL;
-    }
+    open_output_file( AG_SCM_CHARS(new_file), AG_SCM_STRLEN(new_file),
+                      append_mode, 0);
 
-    addWriteAccess( pzNewFile );
-
-    {
-        FILE* fp = fopen( pzNewFile, "a" FOPEN_BINARY_FLAG "+" );
-
-        if (fp == NULL)
-            AG_ABEND( aprf( zCannot, errno, "open for write", pzNewFile,
-                            strerror( errno )));
-        p = (tFpStack*)AGALOC( sizeof( tFpStack ), "append - out file stack" );
-        p->pFile = fp;
-    }
-
-    p->pPrev     = pCurFp;
-    p->flags     = FPF_FREE;
-    p->pzOutName = pzNewFile;
-    outputDepth++;
-    pCurFp       = p;
-    if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
-        fprintf(pfTrace, "appending output to '%s'\n", pzNewFile);
     return SCM_UNDEFINED;
 }
 
@@ -435,25 +448,14 @@ ag_scm_out_push_add( SCM new_file )
 SCM
 ag_scm_out_push_new( SCM new_file )
 {
-    tFpStack* p;
-    char*  pzNewFile;
-
-    p = (tFpStack*)AGALOC( sizeof( tFpStack ), "new - out file stack" );
-    p->pPrev = pCurFp;
-    p->flags = FPF_FREE;
+    static char const write_mode[] = "w" FOPEN_BINARY_FLAG "+";
 
     if (AG_SCM_STRING_P( new_file )) {
-        size_t sz = AG_SCM_STRLEN( new_file );
-        pzNewFile = (char*)AGALOC( sz + 1, "new file name string" );
-        memcpy( pzNewFile, AG_SCM_CHARS( new_file ), sz );
-        pzNewFile[ sz ] = NUL;
-        unlink( pzNewFile );
-        addWriteAccess( pzNewFile );
-        if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
-            fprintf(pfTrace, "creating output to '%s'\n", pzNewFile);
-        p->pFile = fopen( pzNewFile, "a" FOPEN_BINARY_FLAG "+" );
+        open_output_file( AG_SCM_CHARS(new_file), AG_SCM_STRLEN( new_file ),
+                          write_mode, 0);
+        return SCM_UNDEFINED;
     }
-    else
+
 #if defined(ENABLE_FMEMOPEN)
     if (! HAVE_OPT( NO_FMEMOPEN ))
 #endif
@@ -464,43 +466,55 @@ ag_scm_out_push_new( SCM new_file )
          *  the block is executed when a file name is not specified *and*
          *  --no-fmemopen was *not* selected.
          */
-        static char const * pzTemp = NULL;
-        int tmpfd;
+        static char * pzTemp = NULL;
+        static size_t tmplen = 0;
 
-        if (pzTemp == NULL)
+        int     tmpfd;
+
+        if (pzTemp == NULL) {
             pzTemp = mkstempPat();
+            tmplen = strlen(pzTemp) + 1;
+        }
 
-        AGDUPSTR( pzNewFile, pzTemp, "temp file name" );
-        p->flags |= FPF_UNLINK;
-        tmpfd = mkstemp( pzNewFile );
+        memcpy(pzTemp + tmplen, pzTemp, tmplen);
+        tmpfd = mkstemp(pzTemp + tmplen);
         if (tmpfd < 0)
             AG_ABEND( aprf( "failed to create temp file from `%s'", pzTemp ));
 
-        p->pFile  = fopen( pzNewFile, "w" FOPEN_BINARY_FLAG "+" );
-        close( tmpfd );
+        open_output_file(pzTemp + tmplen, tmplen - 1, write_mode, 0);
+        close(tmpfd);
+        return SCM_UNDEFINED;
     }
 #if defined(ENABLE_FMEMOPEN)
-    else
+
     {
+        char *     pzNewFile;
+        tFpStack * p;
+
         /*
-         *  This block is a pure "else" clause that is only compiled if neither
-         *  "fopencookie" nor "funopen" is available in the local C library.
-         *  We reach here if --no-fmemopen was *not* on the command line.
+         *  This block is used IFF ENABLE_FMEMOPEN is defined and if
+         *  --no-fmemopen is selected on the command line.
          */
+        p = (tFpStack*)AGALOC( sizeof( tFpStack ), "new - out file stack" );
+        p->pPrev  = pCurFp;
+        p->flags  = FPF_FREE;
         p->pFile  = ag_fmemopen(NULL, (size_t)0, "wb+");
         pzNewFile = (char*)"in-mem buffer";
         p->flags |= FPF_STATIC_NM | FPF_NOUNLINK | FPF_NOCHMOD;
+
+        if (p->pFile == NULL)
+            AG_ABEND( aprf( zCannot, errno, "open for write", pzNewFile,
+                            strerror( errno )));
+
+        p->pzOutName = pzNewFile;
+        outputDepth++;
+        pCurFp    = p;
+
+        if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
+            fprintf(pfTrace, "out-push-new on temp file\n");
+        return SCM_UNDEFINED;
     }
 #endif /* ENABLE_FMEMOPEN */
-
-    if (p->pFile == NULL)
-        AG_ABEND( aprf( zCannot, errno, "open for write", pzNewFile,
-                        strerror( errno )));
-
-    p->pzOutName = pzNewFile;
-    outputDepth++;
-    pCurFp    = p;
-    return SCM_UNDEFINED;
 }
 
 
@@ -630,64 +644,64 @@ ag_scm_out_line( void )
     return AG_SCM_INT2SCM( lineNum );
 }
 
-#if 0
+#if 0 /* for compilers that do not like C++ comments... */
 // /*=gfunc   make_header_guard
- *
- * what:   make self-inclusion guard
- *
- * exparg: name , header group name
- *
- * doc:
- *   This function will create a @code{#ifndef}/@code{#define}
- *   sequence for protecting a header from multiple evaluation.
- *   It will also set the Scheme variable @code{header-file}
- *   to the name of the file being protected and it will set
- *   @code{header-guard} to the name of the @code{#define} being
- *   used to protect it.  It is expected that this will be used
- *   as follows:
- *   @example
- *   [+ (make-header-guard "group_name") +]
- *   ...
- *   #endif /* [+ (. header-guard) +] */
- *
- *   #include "[+ (. header-file)  +]"
- *   @end example
- *   @noindent
- *   The @code{#define} name is composed as follows:
- *
- *   @enumerate
- *   @item
- *   The first element is the string argument and a separating underscore.
- *   @item
- *   That is followed by the name of the header file with illegal
- *   characters mapped to underscores.
- *   @item
- *   The end of the name is always, "@code{_GUARD}".
- *   @item
- *   Finally, the entire string is mapped to upper case.
- *   @end enumerate
- *
- *   The final @code{#define} name is stored in an SCM symbol named
- *   @code{header-guard}.  Consequently, the concluding @code{#endif} for the
- *   file should read something like:
- *
- *   @example
- *   #endif /* [+ (. header-guard) +] */
- *   @end example
- *
- *   The name of the header file (the current output file) is also stored
- *   in an SCM symbol, @code{header-file}.  Therefore, if you are also
- *   generating a C file that uses the previously generated header file,
- *   you can put this into that generated file:
- *
- *   @example
- *   #include "[+ (. header-file) +]"
- *   @end example
- *
- *   Obviously, if you are going to produce more than one header file from
- *   a particular template, you will need to be careful how these SCM symbols
- *   get handled.
-=*/
+//  *
+//  * what:   make self-inclusion guard
+//  *
+//  * exparg: name , header group name
+//  *
+//  * doc:
+//  * This function will create a @code{#ifndef}/@code{#define}
+//  * sequence for protecting a header from multiple evaluation.
+//  * It will also set the Scheme variable @code{header-file}
+//  * to the name of the file being protected and it will set
+//  * @code{header-guard} to the name of the @code{#define} being
+//  * used to protect it.  It is expected that this will be used
+//  * as follows:
+//  * @example
+//  * [+ (make-header-guard "group_name") +]
+//  * ...
+//  * #endif /* [+ (. header-guard) +] */
+//  *
+//  * #include "[+ (. header-file)  +]"
+//  * @end example
+//  * @noindent
+//  * The @code{#define} name is composed as follows:
+//  *
+//  * @enumerate
+//  * @item
+//  * The first element is the string argument and a separating underscore.
+//  * @item
+//  * That is followed by the name of the header file with illegal
+//  * characters mapped to underscores.
+//  * @item
+//  * The end of the name is always, "@code{_GUARD}".
+//  * @item
+//  * Finally, the entire string is mapped to upper case.
+//  * @end enumerate
+//  *
+//  * The final @code{#define} name is stored in an SCM symbol named
+//  * @code{header-guard}.  Consequently, the concluding @code{#endif} for the
+//  * file should read something like:
+//  *
+//  * @example
+//  * #endif /* [+ (. header-guard) +] */
+//  * @end example
+//  *
+//  * The name of the header file (the current output file) is also stored
+//  * in an SCM symbol, @code{header-file}.  Therefore, if you are also
+//  * generating a C file that uses the previously generated header file,
+//  * you can put this into that generated file:
+//  *
+//  * @example
+//  * #include "[+ (. header-file) +]"
+//  * @end example
+//  *
+//  * Obviously, if you are going to produce more than one header file from
+//  * a particular template, you will need to be careful how these SCM symbols
+//  * get handled.
+// =*/
 #endif
 SCM
 ag_scm_make_header_guard(SCM name)
@@ -725,7 +739,17 @@ ag_scm_make_header_guard(SCM name)
          *  Full, maximal length of output
          */
         size_t hsz = lsz + osz + sizeof(grd) + 1;
-        char * scan_p = AGALOC(hsz, "header guard string");
+        char * scan_p;
+
+        /*
+         * Sanity:
+         */
+        if (*lpz == NUL) {
+            lpz = hdr;
+            lsz = sizeof(hdr) - 1;
+            hsz += lsz;
+        }
+        scan_p = AGALOC(hsz, "header guard string");
 
         gpz = scan_p;
         do  {
@@ -754,7 +778,7 @@ ag_scm_make_header_guard(SCM name)
         static char const setvar[] =
             "(set! header-file \"%s\") "
             "(set! header-guard \"%s\")";
-        char z[sizeof(setvar) + 256];
+        char z[sizeof(setvar) + SCRIBBLE_SIZE];
         char * p = z;
         size_t cmdsz = sizeof(setvar) + gsz + osz;
         if (cmdsz > sizeof(z))
@@ -768,7 +792,7 @@ ag_scm_make_header_guard(SCM name)
 
     {
         static char const ifndef[] = "#ifndef %1$s\n#define %1$s 1";
-        char z[sizeof(ifndef) + 256];
+        char z[sizeof(ifndef) + SCRIBBLE_SIZE];
         char * p = z;
         size_t strsz = sizeof(ifndef) + (2 * gsz);
         if (strsz > sizeof(z))
