@@ -1,16 +1,15 @@
 
 /*
  *  expString.c
- *  $Id: expString.c,v 4.26 2009/01/01 16:51:43 bkorb Exp $
+ *  $Id$
  *
- *  Time-stamp:        "2008-11-16 12:28:30 bkorb"
- *  Last Committed:    $Date: 2009/01/01 16:51:43 $
+ *  Time-stamp:        "2010-02-24 08:42:56 bkorb"
  *
  *  This module implements expression functions that
  *  manipulate string values.
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -27,7 +26,6 @@
  */
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by mk-fwd */
 static size_t
 string_size(char const * pzScn, size_t newLineSize);
 
@@ -111,7 +109,7 @@ makeString( tCC*    pzText,
             tCC*    pzNewLine,
             size_t  newLineSize )
 {
-    char     z[ 256 ];
+    char     z[ SCRIBBLE_SIZE ];
     char*    pzDta;
     char*    pzFre;
     tCC*     pzScn   = pzText;
@@ -428,7 +426,10 @@ do_multi_subs(
              *  passed-in values are freed by the caller.
              */
             if ((pzStr != pzOri) && (pzStr != pzNxt))
+                // coverity[freed_arg] -- invalid alias analysis
                 AGFREE( pzStr );
+
+            // coverity[use_after_free] -- invalid alias analysis
             pzStr = pzNxt;
         }
 
@@ -1065,8 +1066,8 @@ ag_scm_c_string( SCM str )
 SCM
 ag_scm_string_tr_x( SCM str, SCM from_xform, SCM to_xform )
 {
-    char  map[ 256 ];
-    int   i = 255;
+    unsigned char map[ 1 << 8 /* bits-per-byte */ ];
+    int   i      = sizeof(map) - 1;
     char* pzFrom = ag_scm2zchars( from_xform, "string" );
     char* pzTo   = ag_scm2zchars(   to_xform, "string" );
 
@@ -1074,7 +1075,7 @@ ag_scm_string_tr_x( SCM str, SCM from_xform, SCM to_xform )
         map[i] = i;
     } while (--i > 0);
 
-    for (;i <= 255;i++) {
+    for (;i <= sizeof(map) - 1;i++) {
         unsigned char fch = (unsigned char)*(pzFrom++);
         unsigned char tch = (unsigned char)*(pzTo++);
 
