@@ -1,9 +1,8 @@
 
 /*
- *  $Id: funcCase.c,v 4.22 2007/12/02 23:13:15 bkorb Exp $
+ *  $Id$
  *
- *  Time-stamp:        "2007-12-02 15:09:39 bkorb"
- *  Last Committed:    $Date: 2007/12/02 23:13:15 $
+ *  Time-stamp:        "2010-02-24 08:42:12 bkorb"
  *
  *  This module implements the CASE text function.
  */
@@ -11,7 +10,7 @@
 
 /*
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2007 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -77,7 +76,6 @@ static tpLoadProc apCaseLoad[ FUNC_CT ]   = { NULL };
 static tpLoadProc apSelectOnly[ FUNC_CT ] = { NULL };
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by mk-fwd */
 static void
 compile_re(regex_t* pRe, char const * pzPat, int flags);
 
@@ -141,7 +139,7 @@ compile_re(regex_t* pRe, char const * pzPat, int flags)
     void * const pat = (void *)pzPat;
     int  rerr = regcomp(pRe, pat, flags);
     if (rerr != 0) {
-        char zEr[ 128 ];
+        char zEr[ SCRIBBLE_SIZE ];
         regerror( rerr, pRe, zEr, sizeof( zEr ));
         fprintf( stderr, zBadRe, rerr, zEr, pzPat );
         AG_ABEND( "Bad regular expression" );
