@@ -1,14 +1,13 @@
 
 /*
- *  $Id: funcEval.c,v 4.20 2009/01/01 16:49:26 bkorb Exp $
+ *  $Id$
  *
- *  Time-stamp:        "2007-11-12 20:41:59 bkorb"
- *  Last Committed:    $Date: 2009/01/01 16:49:26 $
+ *  Time-stamp:        "2010-02-24 08:42:11 bkorb"
  *
  *  This module evaluates macro expressions.
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -27,7 +26,6 @@
 static int exprType( char* pz );
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by mk-fwd */
 static int
 exprType( char* pz );
 /* = = = END-STATIC-FORWARD = = = */
@@ -229,6 +227,7 @@ evalExpression( ag_bool* pMustFree )
      */
     switch (code) {
     case EMIT_VALUE:
+        assert(pDef != NULL);
         if (*pMustFree) {
             AGFREE( (void*)pzText );
             *pMustFree = AG_FALSE;
@@ -306,11 +305,44 @@ ag_scm_error_source_line( void )
  * exparg: alist, list of arguments to stringify and emit, , list
  *
  * doc:  Walk the tree of arguments, displaying the values of displayable
- *       SCM types.
+ *       SCM types.  EXCEPTION: if the first argument is a number, then
+ *       that number is used to index the output stack.  "0" is the default,
+ *       the current output.
 =*/
 SCM
 ag_scm_emit( SCM val )
 {
+    static int depth = 0;
+    static FILE * fp;
+
+    switch (depth) {
+    case 1:
+    {
+        tFpStack* pSaveFp;
+        unsigned long pnum;
+
+        if (! AG_SCM_NUM_P(val))
+            break;
+
+        pSaveFp = pCurFp;
+        pnum    = gh_scm2ulong(val);
+
+        for (; pnum > 0; pnum--) {
+            pSaveFp = pSaveFp->pPrev;
+            if (pSaveFp == NULL)
+                AG_ABEND(aprf("invalid emission port: %d", gh_scm2ulong(val)));
+        }
+
+        fp = pSaveFp->pFile;
+        return SCM_UNDEFINED;
+    }
+
+    case 0:
+        fp = pCurFp->pFile; // initialize the first time through
+        break;
+    } 
+
+    depth++;
     for (;;) {
         if (val == SCM_UNDEFINED)
             break;
@@ -319,8 +351,8 @@ ag_scm_emit( SCM val )
             break;
 
         if (AG_SCM_STRING_P( val )) {
-            fputs( (char*)ag_scm2zchars( val, "emit val" ), pCurFp->pFile );
-            fflush( pCurFp->pFile );
+            fputs( (char*)ag_scm2zchars( val, "emit val" ), fp );
+            fflush( fp );
             break;
         }
 
@@ -332,14 +364,15 @@ ag_scm_emit( SCM val )
             continue;
 
         default:
-            fputs( resolveSCM( val ), pCurFp->pFile );
-            fflush( pCurFp->pFile );
+            fputs( resolveSCM( val ), fp );
+            fflush( fp );
             break;
         }
 
         break;
     }
 
+    depth--;
     return SCM_UNDEFINED;
 }
 
