@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Sun Dec 23 13:03:28 PST 2007
+ * Generated Wed Mar  3 11:25:20 PST 2010
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD 1
@@ -47,10 +47,10 @@ runShell( char const*  pzCmd );
 /*
  *  Extracted from agUtils.c
  */
-LOCAL char*
+LOCAL char *
 aprf( char const* pzFmt, ... );
 
-LOCAL char*
+LOCAL char *
 mkstempPat( void );
 
 LOCAL void
@@ -65,6 +65,9 @@ spanQuote( char* pzQte );
 LOCAL tCC*
 skipScheme( tCC* pzSrc,  tCC* pzEnd );
 
+LOCAL int
+count_nl(char const * pz);
+
 LOCAL tCC*
 skipExpression( tCC* pzSrc, size_t len );
 
@@ -105,6 +108,9 @@ canonicalizeName( char* pzD, char const* pzS, int srcLen );
 LOCAL tDefEntry*
 findDefEntry( char* pzName, ag_bool* pIsIndexed );
 
+LOCAL void
+print_used_defines(void);
+
 LOCAL tDefEntry**
 findEntryList( char* pzName );
 
@@ -126,6 +132,9 @@ freeEntry( tDefEntry* pDE );
 LOCAL tDefEntry*
 getEntry( void );
 
+LOCAL void
+print_def(tDefEntry * pDef);
+
 LOCAL tDefEntry*
 findPlace( char* name, tCC* pzIndex );
 
@@ -150,6 +159,9 @@ ag_scm_c_eval_string_from_file_line( tCC* pzExpr, tCC* pzFile, int line );
 LOCAL void
 removeWriteAccess( int fd );
 
+LOCAL void
+open_output_file(char const * fname, size_t nmsz, char const * mode, int flags);
+
 /*
  *  Extracted from expPrint.c
  */
@@ -160,7 +172,7 @@ run_printf( char* pzFmt, int len, SCM alist );
  *  Extracted from funcDef.c
  */
 LOCAL void
-parseMacroArgs( tTemplate* pT, tMacro* pMac );
+parseMacroArgs(tTemplate* pT, tMacro* pMac);
 
 /*
  *  Extracted from funcEval.c
