@@ -1,14 +1,13 @@
 
 /*
- *  $Id: tpLoad.c,v 4.26 2009/01/01 16:49:26 bkorb Exp $
+ *  $Id$
  *
- * Time-stamp:        "2008-12-25 11:12:48 bkorb"
- * Last Committed:    $Date: 2009/01/01 16:49:26 $
+ * Time-stamp:        "2010-02-24 08:41:33 bkorb"
  *
  *  This module will load a template and return a template structure.
  *
  * This file is part of AutoGen.
- * AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ * AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -27,7 +26,6 @@
 static tTlibMark magicMark = TEMPLATE_MAGIC_MARKER;
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by mk-fwd */
 static ag_bool
 canReadFile( tCC* pzFName );
 
@@ -348,6 +346,24 @@ loadTemplate(tCC* pzFileName, tCC * pzReferrer)
         AG_ABEND( aprf( zCannot, ENOENT, "map data file", pzFileName,
                         strerror( ENOENT )));
 
+    /*
+     *  Make sure the specified file is a regular file.
+     *  Make sure the output time stamp is at least as recent.
+     */
+    {
+        struct stat stbf;
+        if (stat( zRealFile, &stbf ) != 0)
+            AG_ABEND( aprf( zCannot, errno, "stat template file", pzFileName,
+                            strerror(errno)));
+
+        if (! S_ISREG( stbf.st_mode ))
+            AG_ABEND( aprf( zCannot, EINVAL, "not regular file", pzFileName,
+                            strerror( EINVAL )));
+
+        if (outTime <= stbf.st_mtime)
+            outTime = stbf.st_mtime + 1;
+    }
+
     text_mmap( zRealFile, PROT_READ|PROT_WRITE, MAP_PRIVATE, &mapInfo );
     if (TEXT_MMAP_FAILED_ADDR(mapInfo.txt_data))
         AG_ABEND( aprf( "Could not open template '%s'", zRealFile ));
@@ -356,7 +372,7 @@ loadTemplate(tCC* pzFileName, tCC * pzReferrer)
      *  Process the leading pseudo-macro.  The template proper
      *  starts immediately after it.
      */
-    pCurMacro    = NULL;
+    pCurMacro = NULL;
 
     /*
      *  Count the number of macros in the template.  Compute
