@@ -1,14 +1,13 @@
 /*
  *  agTempl.c
- *  $Id: tpProcess.c,v 4.20 2009/01/01 16:49:26 bkorb Exp $
+ *  $Id$
  *
  *  Parse and process the template data descriptions
  *
- * Time-stamp:        "2007-11-10 15:55:33 bkorb"
- * Last Committed:    $Date: 2009/01/01 16:49:26 $
+ * Time-stamp:        "2010-02-24 08:41:32 bkorb"
  *
  * This file is part of AutoGen.
- * AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ * AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -27,12 +26,11 @@
 static tFpStack fpRoot = { 0, NULL, NULL, NULL };
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by mk-fwd */
 static void
 doStdoutTemplate( tTemplate* pTF );
 
 static void
-openOutFile( tOutSpec* pOutSpec, tFpStack* pStk );
+openOutFile(tOutSpec* pOutSpec);
 /* = = = END-STATIC-FORWARD = = = */
 
 /*
@@ -110,12 +108,7 @@ doStdoutTemplate( tTemplate* pTF )
         return;
 
     default:
-        if (*pzOopsPrefix != NUL) {
-            fprintf( stdout, zBadR, pzOopsPrefix );
-            pzOopsPrefix = zNil;
-        } else {
-            fprintf( pfTrace, zBadR+2 );
-        }
+        fprintf(stdout, zBadR, pzOopsPrefix);
 
     case FAILURE:
         exit( EXIT_FAILURE );
@@ -165,17 +158,6 @@ LOCAL tOutSpec *
 nextOutSpec(tOutSpec * pOS)
 {
     tOutSpec * res = pOS->pNext;
-    /*
-     *  The format is either something inside of zFileFormat, we did not
-     *  allocate it.  If it is specifically zSuffix + strlen + 1, then
-     *  is it part of the pOS allocation.  Otherwise, we deallocate it.
-     */
-    if ((pOS->pzFileFmt < zFileFormat) ||
-        (pOS->pzFileFmt >= zFileFormat + sizeof(zFileFormat))) {
-        char const * pz = pOS->zSuffix + strlen(pOS->zSuffix) + 1;
-        if (pOS->pzFileFmt != pz)
-            AGFREE(pOS->pzFileFmt);
-    }
 
     if (pOS->deallocFmt)
         AGFREE(pOS->pzFileFmt);
@@ -216,22 +198,26 @@ processTemplate( tTemplate* pTF )
          */
         switch (setjmp( fileAbort )) {
         case SUCCESS:
+            if (OPT_VALUE_TRACE >= TRACE_EVERYTHING) {
+                fprintf(pfTrace, "Starting %s template\n", pOS->zSuffix);
+                fflush(pfTrace);
+            }
             /*
              *  Set the output file name buffer.
              *  It may get switched inside openOutFile.
              */
-            openOutFile( pOS, &fpRoot );
-
-            pzCurSfx = pOS->zSuffix;
-            currDefCtx = rootDefCtx;
-            if (OPT_VALUE_TRACE >= TRACE_EVERYTHING) {
-                fprintf( pfTrace, "Starting %s template\n", pzCurSfx );
-                fflush( pfTrace );
-            }
+            openOutFile(pOS);
+            memcpy(&fpRoot, pCurFp, sizeof(fpRoot));
+            AGFREE(pCurFp);
+            pCurFp         = &fpRoot;
+            pzCurSfx       = pOS->zSuffix;
+            currDefCtx     = rootDefCtx;
+            pCurFp->flags &= ~FPF_FREE;
+            pCurFp->pPrev  = NULL;
             generateBlock( pTF, pTF->aMacros, pTF->aMacros + pTF->macroCt );
 
             do  {
-                closeOutput( AG_FALSE );  /* keep output */
+                closeOutput(AG_FALSE);  /* keep output */
             } while (pCurFp->pPrev != NULL);
             break;
 
@@ -318,27 +304,50 @@ closeOutput( ag_bool purge )
 }
 
 
+/*
+ *  Figure out what to use as the base name of the output file.
+ *  If an argument is not provided, we use the base name of
+ *  the definitions file.
+ */
 static void
-openOutFile( tOutSpec* pOutSpec, tFpStack* pStk )
+openOutFile(tOutSpec* pOutSpec)
 {
-    tCC*  pzDefFile;
+    static char const write_mode[] = "w" FOPEN_BINARY_FLAG "+";
+
+    char const * pzDefFile = OPT_ARG( BASE_NAME );
+    char const * pzOutFile = NULL;
+
+    if (strcmp( pOutSpec->zSuffix, "null" ) == 0) {
+        static int const flags = FPF_NOUNLINK;
+    null_open:
+        open_output_file(zDevNull, sizeof(zDevNull)-1, write_mode, flags);
+        return;
+    }
 
     /*
-     *  Figure out what to use as the base name of the output file.
-     *  If an argument is not provided, we use the base name of
-     *  the definitions file.
+     *  IF we are to skip the current suffix,
+     *  we will redirect the output to /dev/null and
+     *  perform all the work.  There may be side effects.
      */
-    pzDefFile = OPT_ARG( BASE_NAME );
+    if (HAVE_OPT( SKIP_SUFFIX )) {
+        int     ct  = STACKCT_OPT(  SKIP_SUFFIX );
+        tCC**   ppz = STACKLST_OPT( SKIP_SUFFIX );
+
+        while (--ct >= 0) {
+            if (strcmp( pOutSpec->zSuffix, *ppz++ ) == 0)
+                goto null_open;
+        }
+    }
 
     /*
      *  Remove any suffixes in the last file name
      */
     {
         char   z[ AG_PATH_MAX ];
-        tCC*   pS = strrchr( pzDefFile, '/' );
+        tCC*   pS = strrchr(pzDefFile, '/');
         char*  pE;
-        if (pS++ == NULL)
-            pS = pzDefFile;
+
+        pS = (pS == NULL) ? pzDefFile : (pS + 1);
 
         /*
          *  We allow users to specify a suffix with '-' and '_', but when
@@ -359,53 +368,13 @@ openOutFile( tOutSpec* pOutSpec, tFpStack* pStk )
          *  Now formulate the output file name in the buffer
          *  provided as the input argument.
          */
-        pStk->pzOutName = aprf( pOutSpec->pzFileFmt, pS,
-                                pOutSpec->zSuffix );
-        if (pStk->pzOutName == NULL)
+        pzOutFile = aprf(pOutSpec->pzFileFmt, pS, pOutSpec->zSuffix);
+        if (pzOutFile == NULL)
             AG_ABEND( aprf( "Cannot format file name:  ``%s''",
                             pOutSpec->pzFileFmt ));
     }
 
-    pCurFp = pStk;
-
-    if (strcmp( pOutSpec->zSuffix, "null" ) == 0) {
-      null_open:
-        /*
-         *  Make the output a no-op, but perform the operations.
-         */
-        AGFREE( (void*)pStk->pzOutName );
-        pStk->pzOutName = zDevNull;
-        pStk->flags    |= FPF_STATIC_NM | FPF_NOUNLINK | FPF_NOCHMOD;
-        pStk->pFile     = fopen( zDevNull, "w" FOPEN_BINARY_FLAG "+" );
-        if (pStk->pFile != NULL)
-            return;
-
-        goto openError;
-    }
-
-    /*
-     *  IF we are to skip the current suffix,
-     *  we will redirect the output to /dev/null and
-     *  perform all the work.  There may be side effects.
-     */
-    if (HAVE_OPT( SKIP_SUFFIX )) {
-        int     ct  = STACKCT_OPT(  SKIP_SUFFIX );
-        tCC**   ppz = STACKLST_OPT( SKIP_SUFFIX );
-
-        while (--ct >= 0) {
-            if (strcmp( pOutSpec->zSuffix, *ppz++ ) == 0)
-                goto null_open;
-        }
-    }
-
-    unlink( pStk->pzOutName );
-    pStk->pFile = fopen( pStk->pzOutName, "w+" FOPEN_BINARY_FLAG );
-
-    if (pStk->pFile == NULL) {
-    openError:
-        AG_ABEND( aprf( zCannot, errno, "create", pStk->pzOutName,
-                        strerror( errno )));
-    }
+    open_output_file(pzOutFile, strlen(pzOutFile), write_mode, 0);
 }
 /*
  * Local Variables:
