@@ -1,7 +1,7 @@
 
 /*
- *  $Id: autoopts.c,v 4.39 2009/01/25 19:31:59 bkorb Exp $
- *  Time-stamp:      "2009-01-12 02:49:49 bkorb"
+ *  $Id$
+ *  Time-stamp:      "2010-02-24 08:41:24 bkorb"
  *
  *  This file contains all of the routines that must be linked into
  *  an executable to use the generated option processing.  The optional
@@ -10,7 +10,7 @@
  *
  *  This file is part of AutoOpts, a companion to AutoGen.
  *  AutoOpts is free software.
- *  AutoOpts is copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ *  AutoOpts is Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *
  *  AutoOpts is available under any one of two licenses.  The license
  *  in use must be one of these two and the choice is under the control
@@ -24,15 +24,14 @@
  *
  *  These files have the following md5sums:
  *
- *  239588c55c22c60ffe159946a760a33e pkg/libopts/COPYING.gplv3
- *  fa82ca978890795162346e661b47161a pkg/libopts/COPYING.lgplv3
+ *  43b91e8ca915626ed3818ffb1b71248b pkg/libopts/COPYING.gplv3
+ *  06a1a2e4760c90ea5e1dad8dfaac4d39 pkg/libopts/COPYING.lgplv3
  *  66a5cedaf62c4b2637025f049f9b826f pkg/libopts/COPYING.mbsd
  */
 
 static char const zNil[] = "";
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by mk-fwd */
 static tSuccess
 findOptDesc( tOptions* pOpts, tOptState* pOptState );
 
@@ -240,7 +239,7 @@ handleOption( tOptions* pOpts, tOptState* pOptState )
     /*
      *  If provided a procedure to call, call it
      */
-    if (pOP != (tpOptProc)NULL)
+    if (pOP != NULL)
         (*pOP)( pOpts, pOD );
 
     return SUCCESS;
@@ -288,7 +287,14 @@ longOptionFind( tOptions* pOpts, char* pzOptName, tOptState* pOptState )
     } else nameLen = strlen( pzOptName );
 
     do  {
-        if (SKIP_OPT(pOD))
+        /*
+         *  If option disabled or a doc option, skip to next
+         */
+        if (pOD->pz_Name == NULL)
+            continue;
+
+        if (  SKIP_OPT(pOD)
+           && (pOD->fOptState != (OPTST_OMITTED | OPTST_NO_INIT)))
             continue;
 
         if (strneqvcmp( pzOptName, pOD->pz_Name, nameLen ) == 0) {
@@ -344,6 +350,17 @@ longOptionFind( tOptions* pOpts, char* pzOptName, tOptState* pOptState )
      *  Make sure we either found an exact match or found only one partial
      */
     if (matchCt == 1) {
+        pOD = pOpts->pOptDesc + matchIdx;
+
+        if (SKIP_OPT(pOD)) {
+            fprintf(stderr, zDisabledErr, pOpts->pzProgName, pOD->pz_Name);
+            if (pOD->pzText != NULL)
+                fprintf(stderr, " -- %s", pOD->pzText);
+            fputc('\n', stderr);
+            (*pOpts->pUsageProc)(pOpts, EXIT_FAILURE);
+            /* NOTREACHED */
+        }
+
         /*
          *  IF we found a disablement name,
          *  THEN set the bit in the callers' flag word
@@ -351,7 +368,7 @@ longOptionFind( tOptions* pOpts, char* pzOptName, tOptState* pOptState )
         if (disable)
             pOptState->flags |= OPTST_DISABLED;
 
-        pOptState->pOD      = pOpts->pOptDesc + matchIdx;
+        pOptState->pOD      = pOD;
         pOptState->pzOptArg = pzEq;
         pOptState->optType  = TOPT_LONG;
         return SUCCESS;
@@ -380,7 +397,7 @@ longOptionFind( tOptions* pOpts, char* pzOptName, tOptState* pOptState )
     if ((pOpts->fOptSet & OPTPROC_ERRSTOP) != 0) {
         fprintf(stderr, (matchCt == 0) ? zIllOptStr : zAmbigOptStr,
                 pOpts->pzProgPath, pzOptName);
-        (*pOpts->pUsageProc)( pOpts, EXIT_FAILURE );
+        (*pOpts->pUsageProc)(pOpts, EXIT_FAILURE);
     }
 
     return FAILURE;
@@ -401,28 +418,28 @@ shortOptionFind( tOptions* pOpts, uint_t optValue, tOptState* pOptState )
     /*
      *  Search the option list
      */
-    for (;;) {
-        /*
-         *  IF the values match,
-         *  THEN we stop here
-         */
-        if ((! SKIP_OPT(pRes)) && (optValue == pRes->optValue)) {
-            pOptState->pOD     = pRes;
-            pOptState->optType = TOPT_SHORT;
-            return SUCCESS;
+    do  {
+        if (optValue != pRes->optValue)
+            continue;
+
+        if (SKIP_OPT(pRes)) {
+            if (  (pRes->fOptState == (OPTST_OMITTED | OPTST_NO_INIT))
+               && (pRes->pz_Name != NULL)) {
+                fprintf(stderr, zDisabledErr, pOpts->pzProgPath, pRes->pz_Name);
+                if (pRes->pzText != NULL)
+                    fprintf(stderr, " -- %s", pRes->pzText);
+                fputc('\n', stderr);
+                (*pOpts->pUsageProc)(pOpts, EXIT_FAILURE);
+                /* NOTREACHED */
+            }
+            goto short_opt_error;
         }
 
-        /*
-         *  Advance to next option description
-         */
-        pRes++;
+        pOptState->pOD     = pRes;
+        pOptState->optType = TOPT_SHORT;
+        return SUCCESS;
 
-        /*
-         *  IF we have searched everything, ...
-         */
-        if (--ct <= 0)
-            break;
-    }
+    } while (pRes++, --ct > 0);
 
     /*
      *  IF    the character value is a digit
@@ -439,6 +456,8 @@ shortOptionFind( tOptions* pOpts, uint_t optValue, tOptState* pOptState )
         return SUCCESS;
     }
 
+ short_opt_error:
+
     /*
      *  IF we are to stop on errors (the default, actually)
      *  THEN call the usage procedure.
