@@ -1,16 +1,14 @@
 
 /*
  *  columns.c
- *  $Id: columns.c,v 4.15 2008/01/23 00:36:06 bkorb Exp $
- *  Time-stamp:        "2007-11-29 11:57:05 bkorb"
+ *  $Id$
+ *  Time-stamp:        "2010-02-24 08:39:31 bkorb"
  *
- *  Columns copyright (c) 1992-2008 Bruce Korb - all rights reserved
- *  Columns copyright (c) 1992-2008 Bruce Korb - all rights reserved
+ *  Columns Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *  Columns is free software.
  *  This file is part of AutoGen.
  *
- *  AutoGen copyright (c) 1992-2008 Bruce Korb - all rights reserved
- *  AutoGen copyright (c) 1992-2008 Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
  *
  *  AutoGen is free software: you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -53,12 +51,17 @@ size_t  columnSz   = 0;
 size_t  indentSize = 0;
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by :mkfwd */
+static void
+fserr_die(char const * fmt, ...);
+
+static inline void *
+malloc_or_die(size_t sz);
+
 static uint32_t
 handleIndent( tCC* pzIndentArg );
 
 static void
-readLines( void );
+readLines(void);
 
 static void
 writeColumns( void );
@@ -66,6 +69,9 @@ writeColumns( void );
 static void
 writeRows( void );
 
+static int
+emitWord(char const * word, size_t len, int col);
+
 static void
 writeFill( void );
 
@@ -74,13 +80,9 @@ compProc( const void* p1, const void* p2 );
 /* = = = END-STATIC-FORWARD = = = */
 
 int
-main( int    argc,
-      char** argv )
+main(int argc, char ** argv)
 {
-    if (optionProcess( &columnsOptions, argc, argv ) != argc) {
-        fputs( "Error:  this program takes no arguments\n", stderr );
-        USAGE( EXIT_FAILURE );
-    }
+    (void)optionProcess( &columnsOptions, argc, argv );
 
     if (HAVE_OPT( INDENT )) {
         indentSize = handleIndent( OPT_ARG( INDENT ));
@@ -113,7 +115,7 @@ main( int    argc,
                 pzFirstPfx = pzLinePfx;
 
             } else if (firstSize < indentSize) {
-                char* tmp = malloc( indentSize + 1 );
+                char* tmp = malloc_or_die( indentSize + 1 );
                 char  z[10];
                 snprintf( z, sizeof(z), "%%-%ds", (int)indentSize );
                 snprintf( tmp, indentSize + 1, z, pzFirstPfx );
@@ -149,32 +151,52 @@ main( int    argc,
 }
 
 
+static void
+fserr_die(char const * fmt, ...)
+{
+    va_list ap;
+    va_start(ap, fmt);
+    fprintf(stderr, "%s fserr %d (%s):  ", columnsOptions.pzProgName,
+            errno, strerror(errno));
+    vfprintf(stderr, fmt, ap);
+    va_end(ap);
+    exit(EXIT_FAILURE);
+}
+
+static inline void *
+malloc_or_die(size_t sz)
+{
+    void * res = malloc(sz);
+    if (res == NULL) {
+        errno = ENOMEM;
+        fserr_die("could not allocate %d bytes", sz);
+    }
+    return res;
+}
+
+
 static uint32_t
 handleIndent( tCC* pzIndentArg )
 {
     char* pz;
-    uint32_t colCt = strtoul( pzIndentArg, &pz, 0 );
+    unsigned int colCt = (unsigned int)strtoul(pzIndentArg, &pz, 0);
 
     /*
      *  IF the indent argument is a number
      */
-    if ((*pz == '\0') && (colCt > 0) && (colCt < OPT_VALUE_WIDTH)) {
+    if ((*pz == NUL) && (colCt > 0) && (colCt < OPT_VALUE_WIDTH)) {
         char* p;
 
         /*
          *  Allocate a string to hold the line prefix
          */
-        pzLinePfx = p = malloc( (size_t)colCt + 1 );
-        if (pzLinePfx == NULL) {
-            fprintf( stderr, "Cannot malloc %d bytes\n", colCt + 1 );
-            exit( EXIT_FAILURE );
-        }
+        pzLinePfx = p = malloc_or_die( (size_t)colCt + 1 );
 
         /*
          *  Set it to a NUL terminated string of spaces
          */
         memset(p, ' ', (size_t)colCt);
-        p[ colCt ] = '\0';
+        p[colCt] = NUL;
 
     } else {
         tCC* p;
@@ -193,7 +215,7 @@ handleIndent( tCC* pzIndentArg )
              *  strings some time in the future, but not now.
              */
             switch (*p++) {
-            case '\0':
+            case NUL:
                 goto colsCounted;
 
             case '\t':
@@ -256,7 +278,7 @@ readLines(void)
             len--;
         }
 
-        *pzText = '\0';
+        *pzText = NUL;
 
         /*
          *  IF the input lines are to be reformatted,
@@ -274,7 +296,7 @@ readLines(void)
          *  Allocate a string and space in the pointer array.
          */
         len += sepLen + 1;
-        pzL = (char*)malloc( len );
+        pzL = (char*)malloc_or_die( len );
         if (++usedCt > allocCt) {
             allocCt += 128;
             papzLines = (char**)realloc( (void*)papzLines,
@@ -389,7 +411,7 @@ writeColumns( void )
         return;
     }
 
-    pPL   = (tpPrintList)malloc( colCt * sizeof( tPrintList ));
+    pPL = (tpPrintList)malloc_or_die( colCt * sizeof( tPrintList ));
 
     /*
      *  This "loop" is normally executed half way through and exited.
@@ -495,7 +517,7 @@ writeColumns( void )
             if (HAVE_OPT( SEPARATION )) {
                 char* pz = pzE + strlen( pzE )
                          - strlen( OPT_ARG( SEPARATION ));
-                *pz = '\0';
+                *pz = NUL;
             }
             fputs( pzE, stdout );
             putc( '\n', stdout );
@@ -514,6 +536,8 @@ writeColumns( void )
         putc( '\n', stdout );
         free( (void*)pzE );
     }
+
+    free(pPL);
 }
 
 
@@ -533,7 +557,7 @@ writeRows( void )
     if (HAVE_OPT( SEPARATION )) {
         char* pz = papzLines[ usedCt-1 ];
         pz += strlen( pz ) - strlen( OPT_ARG( SEPARATION ));
-        *pz = '\0';
+        *pz = NUL;
     }
 
     if (pzFirstPfx != NULL) {
