@@ -1,16 +1,30 @@
 /*
- *  $Id: gdemit.c,v 4.8 2006/09/24 02:59:00 bkorb Exp $
+ *  $Id$
  *
- *    getdefs copyright 1999-2006 Bruce Korb
+ *  getdefs Copyright (c) 1999-2010 by Bruce Korb - all rights reserved
  *
  *  Author:            Bruce Korb <bkorb@gnu.org>
- *  Time-stamp:        "2006-09-23 19:40:08 bkorb"
- *  Last Modified:     $Date: 2006/09/24 02:59:00 $
+ *  Time-stamp:        "2010-02-24 08:38:32 bkorb"
  *            by: bkorb
+ *
+ *  This file is part of AutoGen.
+ *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ *
+ *  AutoGen is free software: you can redistribute it and/or modify it
+ *  under the terms of the GNU General Public License as published by the
+ *  Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  AutoGen is distributed in the hope that it will be useful, but
+ *  WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ *  See the GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by :mkfwd */
 static void
 compressDef( char* pz );
 
@@ -181,11 +195,9 @@ emitDefinition( char* pzDef, char* pzOut )
         while (AG_NAME_CHAR(*pzDef))
             *p++ = *pzOut++ = *pzDef++;
 
-        if (p >= zEntryName + sizeof( zEntryName )) {
-            fprintf( stderr, "getdefs error:  names constrained to %d bytes\n",
-                     MAXNAMELEN );
-            exit( EXIT_FAILURE );
-        }
+        if (p >= zEntryName + sizeof( zEntryName ))
+            die("names are constrained to %d bytes\n", MAXNAMELEN);
+
         *p = NUL;
     }
 
