@@ -1,16 +1,14 @@
 /*
- *  $Id: gdinit.c,v 4.11 2008/01/23 00:36:07 bkorb Exp $
+ *  $Id$
  *
- *    getdefs copyright 1999-2007 Bruce Korb
+ *  getdefs Copyright (c) 1999-2010 by Bruce Korb - all rights reserved
  *
  *  Author:            Bruce Korb <bkorb@gnu.org>
- *  Time-stamp:        "2007-11-04 10:38:57 bkorb"
- *  Last Modified:     $Date: 2008/01/23 00:36:07 $
+ *  Time-stamp:        "2010-02-24 08:38:31 bkorb"
  *            by: bkorb
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2008 Bruce Korb - all rights reserved
- *  AutoGen copyright (c) 1992-2008 Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
  *
  *  AutoGen is free software: you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -29,7 +27,6 @@
 tSCC zNoList[] = "ERROR:  block attr must have name list:\n\t%s\n";
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by mk-fwd */
 static char*
 compressOptionText( char* pzS, char* pzE );
 
@@ -40,6 +37,29 @@ static void
 loadStdin( void );
 /* = = = END-STATIC-FORWARD = = = */
 
+LOCAL void
+die(char const * fmt, ...)
+{
+    va_list ap;
+    va_start(ap, fmt);
+    fprintf(stderr, "%s error:  ", getdefsOptions.pzProgName);
+    vfprintf(stderr, fmt, ap);
+    va_end(ap);
+    exit(EXIT_FAILURE);
+}
+
+LOCAL void
+fserr_die(char const * fmt, ...)
+{
+    va_list ap;
+    va_start(ap, fmt);
+    fprintf(stderr, "%s fserr %d (%s):  ", getdefsOptions.pzProgName,
+            errno, strerror(errno));
+    vfprintf(stderr, fmt, ap);
+    va_end(ap);
+    exit(EXIT_FAILURE);
+}
+
 /*
  *  compressOptionText
  */
@@ -72,10 +92,8 @@ compressOptionText( char* pzS, char* pzE )
     {
         size_t len = (pzD - pzR);
         pzD = malloc( len + 1 );
-        if (pzD == NULL) {
-            fprintf(stderr, "cannot dup %d byte string\n", (int)(pzD - pzR));
-            exit( EXIT_FAILURE );
-        }
+        if (pzD == NULL)
+            die("cannot dup %d byte string\n", (int)(pzD - pzR));
 
         memcpy( pzD, pzR, len );
         pzD[ len ] = NUL;
@@ -106,10 +124,8 @@ fixupSubblockString( tCC* pzSrc )
      */
     {
         char* p = strchr( pzString, '=' );
-        if (p == NULL) {
-            fprintf( stderr, zNoList, pzString );
-            USAGE( EXIT_FAILURE );
-        }
+        if (p == NULL)
+            die(zNoList, pzString);
 
         /*
          *  NUL the equal char
@@ -122,10 +138,9 @@ fixupSubblockString( tCC* pzSrc )
          *  Make sure at least one attribute name is defined
          */
         while (isspace( *p )) p++;
-        if (*p == NUL) {
-            fprintf( stderr, zNoList, pzString );
-            USAGE( EXIT_FAILURE );
-        }
+        if (*p == NUL)
+            die(zNoList, pzString);
+
         pzCopy = p;
     }
 
@@ -134,9 +149,9 @@ fixupSubblockString( tCC* pzSrc )
          *  Attribute names must start with an alpha
          */
         if (! isalpha( *pzCopy )) {
-            fprintf( stderr, "ERROR:  attribute names must start "
-                     "with an alphabetic character:\n\t%s\n",
-                     pzString );
+            fprintf(stderr, "ERROR:  attribute names must start "
+                    "with an alphabetic character:\n\t%s\n",
+                    pzString);
             USAGE( EXIT_FAILURE );
         }
 
@@ -275,30 +290,37 @@ processEmbeddedOptions( char* pzText )
 LOCAL void
 validateOptions( void )
 {
+    static char const default_pat[] =
+        "/\\*=(\\*|"
+        "([a-z][a-z0-9_]*(\\[[0-9]+\\]){0,1}|\\*)[ \t]+[a-z])";
+    static char const pat_wrapper[] = "/\\*=(%s)";
+    ag_bool free_pat = AG_FALSE;
+
     /*
      *  Our default pattern is to accept all names following
      *  the '/' '*' '=' character sequence.  We ignore case.
      */
-    if ((! HAVE_OPT( DEFS_TO_GET )) || (*OPT_ARG( DEFS_TO_GET ) == NUL)) {
-        pzDefPat = "/\\*=(\\*|"
-                   "([a-z][a-z0-9_]*(\\[[0-9]+\\]){0,1}|\\*)[ \t]+[a-z])";
+    if ((! HAVE_OPT(DEFS_TO_GET)) || (*OPT_ARG(DEFS_TO_GET) == NUL)) {
+        pzDefPat = default_pat;
+
+    } else if (strncmp(OPT_ARG(DEFS_TO_GET), default_pat, 4) == 0) {
+        pzDefPat = OPT_ARG(DEFS_TO_GET);
 
     } else {
-        tCC*   pz  = OPT_ARG( DEFS_TO_GET );
+        tCC*   pz  = OPT_ARG(DEFS_TO_GET);
         size_t len = strlen( pz ) + 16;
         char*  bf  = malloc( len );
 
-        if (bf == NULL) {
-            fprintf( stderr, zMallocErr, (int)len, "definition pattern" );
-            exit( EXIT_FAILURE );
-        }
+        if (bf == NULL)
+            die(zMallocErr, (int)len, "definition pattern");
 
         /*
          *  IF a pattern has been supplied, enclose it with
          *  the '/' '*' '=' part of the pattern.
          */
-        snprintf( bf, len, "/\\*=(%s)", pz );
+        snprintf(bf, len, pat_wrapper, pz);
         pzDefPat = bf;
+        free_pat = AG_TRUE;
     }
 
     /*
@@ -313,15 +335,17 @@ validateOptions( void )
         int rerr = regcomp( &define_re, pzDefPat, REG_EXTENDED | REG_ICASE );
         if (rerr != 0) {
             regerror( rerr, &define_re, zRER, sizeof( zRER ));
-            fprintf( stderr, zReErr, rerr, zRER, pzDefPat );
-            exit( EXIT_FAILURE );
+            die(zReErr, rerr, zRER, pzDefPat);
         }
 
+        if (free_pat)
+            free((void *)pzDefPat);
+        pzDefPat = NULL;
+
         rerr = regcomp( &attrib_re, zAttribRe, REG_EXTENDED | REG_ICASE );
         if (rerr != 0) {
             regerror( rerr, &attrib_re, zRER, sizeof( zRER ));
-            fprintf( stderr, zReErr, rerr, zRER, zAttribRe );
-            exit( EXIT_FAILURE );
+            die(zReErr, rerr, zRER, zAttribRe);
         }
     }
 
@@ -357,10 +381,14 @@ validateOptions( void )
         struct stat stb;
 
         if ((ct == 1) && (strcmp( *ppz, "-" ) == 0)) {
+            /*
+             *  Read the list of input files from stdin.
+             */
             loadStdin();
             ct  = STACKCT_OPT(  INPUT );
             ppz = STACKLST_OPT( INPUT );
         }
+
         do  {
             if (stat( *ppz++, &stb ) != 0)
                 break;
@@ -372,11 +400,9 @@ validateOptions( void )
             if (++(stb.st_mtime) > modtime)
                 modtime = stb.st_mtime;
         } while (--ct > 0);
-        if (ct > 0) {
-            fprintf( stderr, "Error %d (%s) stat-ing %s for text file\n",
-                     errno, strerror( errno ), ppz[-1] );
-            USAGE( EXIT_FAILURE );
-        }
+
+        if (ct > 0)
+            fserr_die("stat-ing %s for text file\n", ppz[-1]);
     }
 
     /*
