@@ -1,9 +1,9 @@
 /*
- *  $Id: getdefs.c,v 4.15 2009/01/18 05:52:31 bkorb Exp $
+ *  $Id$
  *
- *    getdefs copyright 1999-2009 by Bruce Korb - all rights reserved
+ *  getdefs Copyright (c) 1999-2010 by Bruce Korb - all rights reserved
  *
- *  Time-stamp:        "2009-01-17 21:27:40 bkorb"
+ *  Time-stamp:        "2010-02-24 08:38:30 bkorb"
  *  Author:            Bruce Korb <bkorb@gnu.org>
  *
  *  This file is part of AutoGen.
@@ -33,7 +33,6 @@ typedef int (compar_func)(const void *, const void *);
 static compar_func compar_text, compar_defname;
 
 /* START-STATIC-FORWARD */
-/* static forward declarations maintained by mk-fwd */
 static char*
 assignIndex( char*  pzOut,  char*  pzDef );
 
@@ -1008,6 +1007,9 @@ startAutogen( void )
             tSCC   zFileFmt[] = " *      %s\n";
             FILE*  fp;
 
+            if (pzBase != NULL)
+                free(pzBase);
+
             if (strcmp( OPT_ARG( OUTPUT ), "-") == 0)
                 return stdout;
 
@@ -1028,8 +1030,12 @@ startAutogen( void )
         }
 
         case INDEX_OPT_AUTOGEN:
-            if (! ENABLED_OPT( AUTOGEN ))
+            if (! ENABLED_OPT( AUTOGEN )) {
+                if (pzBase != NULL)
+                    free(pzBase);
+
                 return stdout;
+            }
 
             if (  ( OPT_ARG( AUTOGEN ) != NULL)
                && (*OPT_ARG( AUTOGEN ) != NUL ))
